/* -*- mode: linux-c -*-
 *
 *      Copyright (C) 2005-2006 Cyrill Gorcunov <gclion@mail.ru>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *      May God bless you!
 *
 */

#include <errno.h>
#include "eprintf.h"

char* eprintf_progname; /* must be set before calling of eprintf;
			 * call EPRINTF_INIT
			 * to do so */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * $Name:	xo_eprintf
 * $Desc:	prints error message
 * $Args:	(i) file - source file filename (use __FILE__)
 *		(i) line - source file line number (use __LINE__)
 *		(i) fmt - special formatted string, if it ends with
 *		':' sign then it prints system error description
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
void xo_eprintf(char* file, int line, char *fmt, ...)
{
	va_list args;

	fflush(stderr);
	if (eprintf_progname != NULL && file != NULL && line > 0)
		fprintf(stderr,
			"%s: error <%s:%i>: ",
			eprintf_progname,
			file,
			line);

	va_start(args, fmt);
	vfprintf(stderr, fmt, args);
	va_end(args);

	if (fmt[0] != '\0' && fmt[strlen(fmt)-1] == ':')
		fprintf(stderr,
			" %s",
			strerror(errno));
	fprintf(stderr, "\n");
}


/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * $Name:	dprintf
 * $Desc:	prints message to stdout
 * $Args:	(i) file - source file filename (use __FILE__)
 *		(i) line - source file line number (use __LINE__)
 *		(i) fmt - special formatted string, if it ends with
 *		':' sign then it prints system error description
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
void xo_dprintf(char* file, int line, char *fmt, ...)
{
	va_list args;

	fflush(stdout);
	if (eprintf_progname != NULL && file != NULL && line > 0)
		fprintf(stdout,
			"%s: debug <%s:%i>: ",
			eprintf_progname,
			file,
			line);

	va_start(args, fmt);
	vfprintf(stdout, fmt, args);
	va_end(args);

	fprintf(stdout, "\n");
}
